<?xml version="1.0"?>

<!-- i-mode用、テストXSLT変換 -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:it="http://www.piedey.co.jp/xmlns/modulaf/interim"
                xmlns:sd="http://www.piedey.co.jp/xmlns/modulaf/sitedef"
				xmlns:wd="http://www.piedey.co.jp/xmlns/modulaf/worddef"
				xmlns:wr="http://www.piedey.co.jp/xmlns/modulaf/wordref"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:peru="http://webservices.amazon.com/AWSECommerceService/2009-03-31"
                xmlns="http://www.w3.org/1999/xhtml"
                exclude-result-prefixes="it sd wd wr xhtml peru">

	<xsl:output method="html" encoding="Shift_JIS" />

	<xsl:param name="hostUriPath" />
	<xsl:param name="encodedRelativeURIWithoutFragmentIdentifier" />
	<xsl:param name="mf_addbase" />
	<xsl:param name="mf_dbase" />

	<xsl:variable name="pageClass" select="/it:modulafContent/@pageClass" />
	<xsl:variable name="sitedef" select="document(string(/it:modulafContent/@sitedef))" />
	<xsl:variable name="words" select="$sitedef/sd:siteDefinition/sd:term" />
	<xsl:variable name="group" select="$sitedef/sd:siteDefinition/sd:group[@pageClass=$pageClass]" />

	<!-- よく使われ、文脈で変化しない値を変数に入れておく -->
	<xsl:variable name="primaryCode" select="//it:module[@primary='true']/it:keyword/it:item[position()=last()]/@code" />
	<xsl:variable name="contentID" select="//it:module[@primary='true']/it:contentID" />
	<xsl:variable name="keywordName" select="//it:module[@primary='true']/it:keyword/it:item[position()=last()]/it:title" />

	<!-- 属性、コメント、テキストはデフォルトで素通し -->
	<xsl:template match="@*|comment()|text()">
		<xsl:copy><xsl:apply-templates select="@*|*|comment()|text()"></xsl:apply-templates></xsl:copy>
	</xsl:template>

	<!-- 不必要な名前空間宣言が出力されてしまう問題(MSXMLのバグ?)を回避するためのhack -->
	<xsl:template match="*">
		<xsl:element name="{name()}">
			<xsl:apply-templates select="@*|*|comment()|text()"/>
		</xsl:element>
	</xsl:template>

	<!-- これらの要素を空要素タグとして出力させるhack -->
	<xsl:template match="xhtml:br|xhtml:hr|xhtml:img|xhtml:base|xhtml:meta|xhtml:link|xhtml:param|xhtml:area|xhtml:input|xhtml:col">
		<xsl:text disable-output-escaping="yes">&lt;</xsl:text>
		<xsl:value-of select="name()" />
		<xsl:for-each select = "@*">
			<xsl:text> </xsl:text>
			<xsl:value-of disable-output-escaping="yes" select="name()" />
			<xsl:text>=</xsl:text>
			<xsl:text disable-output-escaping="yes">"</xsl:text>
			<xsl:value-of select="." />
			<xsl:text disable-output-escaping="yes">"</xsl:text>
		</xsl:for-each>
		<xsl:text disable-output-escaping="yes"> /></xsl:text>
	</xsl:template>

	<!-- i-mode HTMLにはない要素は無視させる (簡易実装) -->
	<xsl:template match="xhtml:table">
		<xsl:apply-templates/>
	</xsl:template>

	<!-- i-mode HTMLにはないth/td要素は区切りの空白を足した上で無視させる (簡易実装) -->
	<xsl:template match="xhtml:table|xhtml:td|xhtml:th">
		<xsl:apply-templates/><xsl:text> </xsl:text>
	</xsl:template>

	<!-- i-mode HTMLにはないtr要素はp要素扱いとする (簡易実装) -->
	<xsl:template match="xhtml:tr">
		<p><xsl:apply-templates/></p>
	</xsl:template>

	<!-- 属性値にマクロが書けないことへの対策 -->
	<xsl:template match="it:attribute">
		<xsl:attribute name="{it:name}"><xsl:apply-templates select="it:value/*|it:value/text()" /></xsl:attribute>
	</xsl:template>

	<xsl:template name="contactlist">
		<xsl:param name="list" />
		<xsl:param name="title" />
		<xsl:param name="pclass" />
		<xsl:for-each select = "$list">
			<p>
				<xsl:value-of select="$title" />: 
				<xsl:apply-templates select="it:name/*|it:name/text()" />
				<xsl:if test="it:email[1]/@gifImageUri" >
					<img>
						<xsl:attribute name="src"><xsl:value-of select="it:email[1]/@gifImageUri" /></xsl:attribute>
						<xsl:attribute name="alt"><xsl:value-of select="$words/wd:contact" /></xsl:attribute>
					</img>
				</xsl:if>
			</p>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="sd:*">
		<xsl:param name="count" />
		<xsl:param name="keywordIdentifier" />
		<xsl:param name="contentIdentifier" />
		<xsl:param name="pictureWidth" />
		<xsl:param name="attachedFileNumber" />
		<xsl:param name="fragmentIdentifier" />

		<xsl:choose>
			<xsl:when test = "name(.) = 'sd:pictureWidth'"><xsl:value-of select='$pictureWidth'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:attachedFileNumber'"><xsl:value-of select='$attachedFileNumber'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:fragmentIdentifier'"><xsl:value-of select='$fragmentIdentifier'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:hostUriPath'"><xsl:value-of select='$hostUriPath'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:encodedRelativeURIWithoutFragmentIdentifier'"><xsl:value-of select='$encodedRelativeURIWithoutFragmentIdentifier'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:count'">
				<xsl:value-of select='$count'/>
			</xsl:when>
			<xsl:when test = "name(.) = 'sd:keywordName'">
				<xsl:value-of select='$keywordName'/>
			</xsl:when>
			<xsl:when test = "name(.) = 'sd:keywordIdentifier'">
				<xsl:value-of select='$keywordIdentifier'/>
			</xsl:when>
			<xsl:when test = "name(.) = 'sd:contentIdentifier'">
				<xsl:value-of select='$contentIdentifier'/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates>
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
					<xsl:with-param name="pictureWidth" select= "$pictureWidth" />
					<xsl:with-param name="attachedFileNumber" select= "$attachedFileNumber" />
					<xsl:with-param name="fragmentIdentifier" select= "$fragmentIdentifier" />
				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

  <xsl:template match="it:xhtml">
      <xsl:value-of disable-output-escaping="yes" select="."/>
  </xsl:template>

  <xsl:template match="it:whiteSeparatorBetweenParagraphs">
		<br />
	</xsl:template>

	<xsl:template name="errorPeruItem">
		<h2><xsl:value-of select="it:error/it:title"/></h2>
		<xsl:apply-templates select="it:error/it:body/*|it:error/it:body/text()" />
	</xsl:template>

	<xsl:template name="normalShortPeruItem">
		<tr>
		<td class="peruShort">
			<p class="shortPeruPicture">
			<xsl:if test="peru:ItemLookupResponse/peru:Items/peru:Item/peru:SmallImage/peru:URL/text()">
				<a href="{it:peruPurchaseLink}">
				<img class="shortPeruPicture" src="{peru:ItemLookupResponse/peru:Items/peru:Item/peru:SmallImage/peru:URL}"
					width="{peru:ItemLookupResponse/peru:Items/peru:Item/peru:SmallImage/peru:Width}"
					height="{peru:ItemLookupResponse/peru:Items/peru:Item/peru:SmallImage/peru:Height}"
					alt="{peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Title}" 
					/></a>
				<br />
			</xsl:if>
			<a href="{it:peruPurchaseLink}"><xsl:value-of select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Title"/></a>
			<xsl:for-each select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Author">
				<br />
				<xsl:value-of select="."/>
			</xsl:for-each>
			<xsl:for-each select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Artist">
				<br />
				<xsl:value-of select="."/>
			</xsl:for-each>
			<xsl:for-each select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Actor">
				<br />
				<xsl:value-of select="."/>
			</xsl:for-each>
			<br />
			-----
			<xsl:if test="peru:ItemLookupResponse/peru:Items/peru:Item/peru:OfferSummary/peru:LowestUsedPrice/peru:FormattedPrice">
				<br />
				<span class="peruShortHead">Used Price:</span><br /><xsl:value-of select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:OfferSummary/peru:LowestUsedPrice/peru:FormattedPrice"/>
			</xsl:if>
			<xsl:if test="peru:ItemLookupResponse/peru:Items/peru:Item/peru:OfferSummary/peru:LowestNewPrice/peru:FormattedPrice">
				<br />
				<span class="peruShortHead">Price:</span><br /><xsl:value-of select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:OfferSummary/peru:LowestNewPrice/peru:FormattedPrice"/>
			</xsl:if>
			</p>
		</td>
		</tr>
	</xsl:template>

	<xsl:template match="it:shortPeruList">
		<xsl:if test="it:item">
			<xsl:for-each select = "it:item">
				<xsl:choose>
					<xsl:when test = "it:error">
						<xsl:call-template name="errorPeruItem" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="normalShortPeruItem" />
					</xsl:otherwise> 
				</xsl:choose>
			</xsl:for-each>
			by <a href="http://www.amazon.co.jp/">Amazon.co.jp</a>
		</xsl:if>
	</xsl:template>

	<xsl:template match="it:attachedFileMenu">
		<p class="attachMenuForNormal"><a href="{it:uri}"><xsl:value-of select="it:description" /></a></p>
	</xsl:template>

	<xsl:template match="it:pictureFileMenu">
		<xsl:variable name="fileNumber" select="@fileNumber" />
		<xsl:variable name="fragmentID" select="concat('F',$fileNumber)" />
		<xsl:variable name="contentIdentifier" select="ancestor::it:module/it:contentID" />

		<p id="{$fragmentID}">
			<xsl:apply-templates select="it:description/*|it:description/text()" />

			<xsl:for-each select = "it:sizes/it:size">
				[<a>
					<xsl:choose>
						<xsl:when test="position() = last()" >
								<xsl:attribute name="href">
									<xsl:apply-templates select="$group/sd:picturePageURI">
										<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
										<xsl:with-param name="attachedFileNumber" select= "$fileNumber" />
										<xsl:with-param name="fragmentIdentifier" select= "$fragmentID" />
										<xsl:with-param name="pictureWidth" select= "''" />
									</xsl:apply-templates>
								</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
								<xsl:attribute name="href">
									<xsl:apply-templates select="$group/sd:picturePageURI">
										<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
										<xsl:with-param name="attachedFileNumber" select= "$fileNumber" />
										<xsl:with-param name="fragmentIdentifier" select= "$fragmentID" />
										<xsl:with-param name="pictureWidth" select= "@width" />
									</xsl:apply-templates>
								</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:value-of select="@width" />x<xsl:value-of select="@height" />
				</a>]
			</xsl:for-each>
		</p>
	</xsl:template>

	<xsl:template match="it:menu">
		<xsl:call-template name="horizontalLine" />
		<p>
			<xsl:for-each select = "$group/sd:menu/sd:item">
			[<a>
				<xsl:attribute name = "href">
					<xsl:apply-templates select="sd:URI">
						<xsl:with-param name="keywordIdentifier" select="$primaryCode" />
						<xsl:with-param name="contentIdentifier" select="$contentID" />
					</xsl:apply-templates>
				</xsl:attribute>
				<xsl:apply-templates select="sd:name" />
			</a>]

			</xsl:for-each>
		</p>
	</xsl:template>

	<xsl:template match="it:administrator">
		<xsl:if test="//it:pageInfo/it:administrator">
			<xsl:call-template name="contactlist">
				<xsl:with-param name="list" select="//it:pageInfo/it:administrator" />
				<xsl:with-param name="title"><xsl:value-of select="$words/wd:administrator" /></xsl:with-param>
				<xsl:with-param name="pclass">author</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template match="wr:*">
		<xsl:param name="count" />
		<xsl:param name="keywordIdentifier" />
		<xsl:param name="contentIdentifier" />
		<xsl:variable name="localName" select= "local-name(.)" />
		<xsl:variable name="targetNodes" select= "$words/wd:*[local-name(.) = $localName]" />

		<xsl:choose>
			<xsl:when test="@keywordIdentifier">
				<xsl:apply-templates select="$targetNodes">
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "@keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="$targetNodes">
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<xsl:template match="wd:*">
		<xsl:param name="count" />
		<xsl:param name="keywordIdentifier" />
		<xsl:param name="contentIdentifier" />
		<xsl:param name="attachedFileNumber" />
		<xsl:param name="fragmentIdentifier" />
		<xsl:param name="pictureWidth" />
		<xsl:apply-templates>
			<xsl:with-param name="count" select= "$count" />
			<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
			<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
			<xsl:with-param name="attachedFileNumber" select= "$attachedFileNumber" />
			<xsl:with-param name="fragmentIdentifier" select= "$fragmentIdentifier" />
			<xsl:with-param name="pictureWidth" select= "$pictureWidth" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template name="horizontalLine">
		<hr />
	</xsl:template>

	<xsl:template name="keywordSub">
		<xsl:param name="itemlist" />
		<xsl:for-each select = "$itemlist">
			<xsl:if test = "position() != 1">
				<xsl:text>→</xsl:text>
			</xsl:if>
			<a>
				<xsl:choose>
					<xsl:when test = "@code = ''">
						<xsl:attribute name = "href"><xsl:value-of select="$group/sd:siteTopURI" /></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name = "href">
							<xsl:apply-templates select="$group/sd:keywordTopURI">
								<xsl:with-param name="keywordIdentifier" select= "@code" />
							</xsl:apply-templates>
						</xsl:attribute>
					</xsl:otherwise> 
				</xsl:choose>
				<xsl:apply-templates select="it:title/*|it:title/text()"/>
			</a>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="it:contentNavigation">
		<p>
		前

		<xsl:value-of select="$words/wd:keyword" />内の前後の<xsl:value-of select="$words/wd:content" />
		次
		</p>
		<xsl:for-each select = "it:keyword[1]/it:item">
			<xsl:sort select = "position()" data-type = "number" order = "descending"/>
			<xsl:variable name="length" select="last()-position()+1" />
			<p>
				<xsl:if test="it:prev" >
					<a>
						<xsl:attribute name = "href">
							<xsl:apply-templates select="$group/sd:contentURI">
								<xsl:with-param name="contentIdentifier" select= "it:prev/it:contentID" />
							</xsl:apply-templates>
						</xsl:attribute>←
					</a>
				</xsl:if>

				<xsl:call-template name="keywordSub">
					<xsl:with-param name="itemlist" select= "../it:item[position() &lt;= $length]" />
				</xsl:call-template>

				<xsl:if test="it:next" >
					<a>
						<xsl:attribute name = "href">
							<xsl:apply-templates select="$group/sd:contentURI">
								<xsl:with-param name="contentIdentifier" select= "it:next/it:contentID" />
							</xsl:apply-templates>
						</xsl:attribute>→

					</a>
				</xsl:if>
			</p>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="keyword">
		<xsl:call-template name="keywordSub">
			<xsl:with-param name="itemlist" select= "it:keyword[1]/it:item" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="it:trackBackList">
		<xsl:if test="it:item">
			<h2 ><xsl:value-of select="$words/wd:trackback" />一覧</h2>
			<xsl:for-each select = "it:item">
				<xsl:sort select="position()" order="descending" />
				<p>
					<xsl:value-of select='it:date'/>
					<xsl:value-of select='it:title'/>
					From: <xsl:value-of select='it:from'/>
				</p>
				<p><xsl:value-of select='it:digest'/> 
					<a>
					<xsl:attribute name="href"><xsl:value-of select='it:uri'/></xsl:attribute>
					続きを読む</a>
				</p>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

	<xsl:template match="it:trackBackURI">
		<xsl:for-each select = "it:item">
			<p>
				<xsl:apply-templates select='*|text()'>
					<xsl:with-param name="contentIdentifier" select= "../../it:contentID" />
				</xsl:apply-templates>
			</p>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="keywordAndCount">
		<p>
			<xsl:if test="it:keyword">
					<xsl:call-template name="keyword" />
				
			</xsl:if>
			<xsl:if test="it:totalAccessCount">
					<xsl:apply-templates select="$words/wd:totalAccessCount">
						<xsl:with-param name="count" select= "it:totalAccessCount[1]" />
					</xsl:apply-templates>
				
			</xsl:if>
		</p>
	</xsl:template>

	<xsl:template name="contentTitle">
		<xsl:choose>
			<xsl:when test="@primary='true' and it:contentID">
				<h1 >
					<a >
						<xsl:attribute name = "href">
							<xsl:apply-templates select="$group/sd:contentURI">
								<xsl:with-param name="contentIdentifier" select= "it:contentID[1]" />
							</xsl:apply-templates>
						</xsl:attribute>
						<xsl:apply-templates select='it:title/*|it:title/text()'/>
					</a>
				</h1>
			</xsl:when>
			<xsl:when test="@primary='true' and not(it:contentID)">
				<h1 >
					<xsl:apply-templates select='it:title/*|it:title/text()'/>
				</h1>
			</xsl:when>
			<xsl:otherwise>
				<h2 >
					<xsl:apply-templates select='it:title/*|it:title/text()'/>
				</h2>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="boxedModuleHeader">
		<xsl:if test="it:date[1]">
			<xsl:value-of select='it:date[1]'/>
		</xsl:if>
		<xsl:if test="it:keyword or it:totalAccessCount">
			<xsl:call-template name="keywordAndCount" />
		</xsl:if>
		<xsl:call-template name="contentTitle" />
	</xsl:template>

	<xsl:template name="boxedModule">
		<xsl:param name="tableClass" />

		<xsl:call-template name="boxedModuleHeader" />

		<xsl:if test="it:author">
			<xsl:call-template name="contactlist">
				<xsl:with-param name="list" select="it:author" />
				<xsl:with-param name="title"><xsl:value-of select="$words/wd:author" /></xsl:with-param>
				<xsl:with-param name="pclass">author</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="it:body/*|it:body/text()" />

		<xsl:apply-templates select="it:contentNavigation" />

		<xsl:apply-templates select="it:trackBackList" />

		<xsl:apply-templates select="it:trackBackURI" />
	</xsl:template>

	<xsl:template name="planeModuleSubSub">
		<xsl:if test="*">
			<xsl:if test="it:iconPicture[1]">
				<p>
					<img>
						<xsl:attribute name="src"><xsl:value-of select="it:iconPicture[1]" /></xsl:attribute>
						<xsl:attribute name="alt"><xsl:value-of select="$words/wd:iconPicture" /></xsl:attribute>
					</img>
				</p>
			</xsl:if>
			<xsl:if test="it:date[1]">
				<p><xsl:value-of select='it:date[1]'/></p>
			</xsl:if>
			<xsl:if test="it:keyword or it:totalAccessCount">
				<xsl:call-template name="keywordAndCount" />
			</xsl:if>
			<xsl:if test="it:title">
				<xsl:call-template name="contentTitle" />
			</xsl:if>
			<xsl:if test="it:author">
				<xsl:call-template name="contactlist">
					<xsl:with-param name="list" select="it:author" />
					<xsl:with-param name="title"><xsl:value-of select="$words/wd:author" /></xsl:with-param>
					<xsl:with-param name="pclass">author</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:apply-templates select="it:body/*|it:body/text()" />

			<xsl:apply-templates select="it:contentNavigation" />

			<xsl:apply-templates select="it:trackBackList" />

			<xsl:apply-templates select="it:trackBackURI" />
		</xsl:if>
	</xsl:template>

	<!-- プレーンな(ボックスに入っていない)モジュールを生成する -->
	<!-- しかし、referListの場合はボックスが出てしまう。やむなし -->
	<xsl:template name="planeModuleSub">
		<xsl:if test="*">
			<xsl:choose>
				<xsl:when test = "it:referList">
					<xsl:call-template name="referListModule" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="planeModuleSubSub" />
				</xsl:otherwise> 
			</xsl:choose>
		</xsl:if>
	</xsl:template>

	<xsl:template name="planeModule">
		<xsl:choose>
			<xsl:when test = "@option = 'external'" >
				<xsl:call-template name="linkExternal" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="planeModuleSub" />
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:template>

	<xsl:template name="keywordAndAccessCountForReferListModule">
		<p>
			<xsl:call-template name="keywordSub">
				<xsl:with-param name="itemlist" select= "it:keyword[1]/it:item" />
			</xsl:call-template>
			
			<xsl:choose>
				<xsl:when test = "(it:totalAccessCount[1]) and not(it:rank)">
					<xsl:apply-templates select="$words/wd:totalAccessCount">
						<xsl:with-param name="count" select= "it:totalAccessCount[1]" />
					</xsl:apply-templates>
				</xsl:when>
				<xsl:when test = "(it:recentlyAccessCount[1]) and (it:rank)">
					<xsl:apply-templates select="$words/wd:recentlyAccessCount">
						<xsl:with-param name="count" select= "it:recentlyAccessCount[1]" />
					</xsl:apply-templates>
				</xsl:when>
			</xsl:choose>
		</p>
	</xsl:template>

	<xsl:template name="referListModule">
		<xsl:if test="it:title">
		<xsl:choose>
			<xsl:when test = "@primary = 'true'">
				<h1><xsl:apply-templates select="it:title/*|it:title/text()" /></h1>
			</xsl:when>
			<xsl:otherwise>
				<h2><xsl:apply-templates select="it:title/*|it:title/text()" /></h2>
			</xsl:otherwise> 
		</xsl:choose>
		</xsl:if>
		<xsl:if test="it:date[1]">
			<p><xsl:value-of select='it:date[1]'/></p>
		</xsl:if>
		<xsl:if test="it:keyword or it:totalAccessCount">
			<xsl:call-template name="keywordAndCount" />
		</xsl:if>
		<xsl:if test="it:author">
			<xsl:call-template name="contactlist">
				<xsl:with-param name="list" select="it:author" />
				<xsl:with-param name="title"><xsl:value-of select="$words/wd:author" /></xsl:with-param>
				<xsl:with-param name="pclass">author</xsl:with-param>
			</xsl:call-template>
		</xsl:if>

		<xsl:apply-templates select="it:body/*|it:body/text()" />

		<xsl:for-each select = "it:referList/it:item">
			<p>
				<xsl:if test="../it:item/it:rank" >
					<xsl:if test="it:rank" >
						No.<xsl:value-of select="it:rank"/>
					</xsl:if>
				</xsl:if>
				<xsl:if test="../it:item/it:lastUpdatedDate" >
					最終更新 
					<xsl:choose>
						<xsl:when test="it:lastUpdatedDate" >
								<xsl:value-of select="it:lastUpdatedDate"/>
						</xsl:when>
						<xsl:otherwise>
							(なし)
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				
				<xsl:if test="it:date" >
					<xsl:value-of select="it:date"/>
				</xsl:if>
				<xsl:if test="(it:keyword[1]/it:item) or (it:totalAccessCount[1]) or (it:recentlyAccessCount[1])" >
					<xsl:call-template name="keywordAndAccessCountForReferListModule"/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="it:URI[1]" >
						<a>
							<xsl:attribute name = "href">
								<xsl:apply-templates select='it:URI/*|it:URI/text()'/>
							</xsl:attribute>
							<xsl:apply-templates select='it:title/*|it:title/text()'/>
						</a>
					</xsl:when>
					<xsl:when test="it:contentID[1]" >
						<a>
							<xsl:attribute name = "href">
								<xsl:apply-templates select="$group/sd:contentURI">
									<xsl:with-param name="contentIdentifier" select= "it:contentID[1]" />
								</xsl:apply-templates>
							</xsl:attribute>
							<xsl:apply-templates select='it:title/*|it:title/text()'/>
						</a>
					</xsl:when>
				</xsl:choose>
			</p>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="linkExternal">
		<p>[<a>
		<xsl:attribute name="href"><xsl:value-of select="$mf_addbase" />mf_ext=<xsl:value-of select="@id" /></xsl:attribute>
		<xsl:apply-templates select="it:title/*|it:title/text()" /></a>]</p>
	</xsl:template>

	<xsl:template name="normalModule">
		<xsl:param name="tableClass" />
		<xsl:choose>
			<xsl:when test = "it:shortPeruList">
				<xsl:apply-templates select="it:shortPeruList" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="*">
					<xsl:choose>
						<xsl:when test = "@option = 'external'" >
							<xsl:call-template name="linkExternal" />
						</xsl:when>
						<xsl:when test = "it:referList">
							<xsl:call-template name="referListModule" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="boxedModule" >
								<xsl:with-param name="tableClass" select="$tableClass" />
							</xsl:call-template>
						</xsl:otherwise> 
					</xsl:choose>
 				</xsl:if>
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:template>

	<xsl:template name="primaryHeaderModule">
		<xsl:if test="*">
			<xsl:choose>
				<xsl:when test = "it:keyword/it:item[last()]/@code=''">
					<h1 ><xsl:value-of select="//it:pageInfo/it:siteName" /></h1>
				</xsl:when>
				<xsl:otherwise>
					<p ><xsl:value-of select="//it:pageInfo/it:siteName" /></p>
					<p><xsl:call-template name="keyword" /></p>
					<h1 ><xsl:value-of select="it:keyword/it:item[last()]/it:title" /></h1>
				</xsl:otherwise> 
			</xsl:choose>
		</xsl:if>
	</xsl:template>

	<xsl:template name="main">
		<xsl:call-template name="normalModule" />
	</xsl:template>

	<xsl:template name="header">
		<xsl:choose>
			<xsl:when test = "@primary = 'true'">
				<xsl:call-template name="primaryHeaderModule" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="planeModule" />
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:template>

	<xsl:template name="footer">
		<xsl:call-template name="planeModule" />
	</xsl:template>

	<xsl:template name="left">
		<xsl:call-template name="normalModule" >
			<xsl:with-param name="tableClass">thin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="right">
		<xsl:call-template name="normalModule" >
			<xsl:with-param name="tableClass">thin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="upper">
		<xsl:call-template name="normalModule" >
			<xsl:with-param name="tableClass">thin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="lower">
		<xsl:call-template name="normalModule" >
			<xsl:with-param name="tableClass">thin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="generateDivLink">
		<xsl:param name="number" />
		<xsl:param name="label" />
		[<xsl:choose>
			<xsl:when test="$number = /it:modulafContent/it:div/@number">
				<xsl:value-of select="$number" />
			</xsl:when>
			<xsl:otherwise>
				<a>
				<xsl:attribute name="href"><xsl:value-of select="$mf_dbase" />mf_d=<xsl:value-of select="$number" /></xsl:attribute>
				<xsl:value-of select="$label" />
				</a>
			</xsl:otherwise>
		</xsl:choose>]
	</xsl:template>

	<xsl:template name="generateDivLinkRelative">
		<xsl:param name="number" />
		<xsl:if test="$number > 1 and /it:modulafContent/it:div/@all > $number">
			<xsl:call-template name="generateDivLink">
				<xsl:with-param name="number"><xsl:value-of select="$number" /></xsl:with-param>
				<xsl:with-param name="label"><xsl:value-of select="$number" /></xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template name="generateDivLinkRelativeAll">
		<xsl:param name="number" />
		<xsl:param name="label" />
		<xsl:if test="$number >= 1 and /it:modulafContent/it:div/@all >= $number">
			<xsl:call-template name="generateDivLink">
				<xsl:with-param name="number"><xsl:value-of select="$number" /></xsl:with-param>
				<xsl:with-param name="label"><xsl:value-of select="$label" /></xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template name="divNavigation">
		<xsl:if test="/it:modulafContent/it:div">
			<p>分割されたページ: 

				<!-- 1st item -->
				<xsl:call-template name="generateDivLink">
					<xsl:with-param name="number">1</xsl:with-param>
					<xsl:with-param name="label">先頭(1)</xsl:with-param>
				</xsl:call-template>

				<!-- ← -->
				<xsl:call-template name="generateDivLinkRelativeAll">
					<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@number - 1" /></xsl:with-param>
					<xsl:with-param name="label">前頁(<xsl:value-of select="/it:modulafContent/it:div/@number - 1" />)</xsl:with-param>
				</xsl:call-template>

				<!-- → -->
				<xsl:call-template name="generateDivLinkRelativeAll">
					<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@number + 1" /></xsl:with-param>
					<xsl:with-param name="label">次頁(<xsl:value-of select="/it:modulafContent/it:div/@number + 1" />)</xsl:with-param>
				</xsl:call-template>

				<!-- last item -->
				<xsl:if test="/it:modulafContent/it:div/@all > 1">
					<xsl:call-template name="generateDivLink">
						<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@all" /></xsl:with-param>
						<xsl:with-param name="label">末尾(<xsl:value-of select="/it:modulafContent/it:div/@all" />)</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</p>
		</xsl:if>
	</xsl:template>

	<xsl:template name="divNext">
		<xsl:if test="/it:modulafContent/it:div and (/it:modulafContent/it:div/@all > /it:modulafContent/it:div/@number)">
			<p>(<a><xsl:attribute name="href"><xsl:value-of select="$mf_dbase" />mf_d=<xsl:value-of select="/it:modulafContent/it:div/@number + 1" /></xsl:attribute>続き...</a>)</p>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/">
		<html lang="ja-JP" xml:lang="ja-JP">
		<head>
		<title><xsl:apply-templates select="//it:module[@primary='true']/it:title/*|//it:module[@primary='true']/it:title/text()"/></title>
		</head>
		<body>
			<xsl:for-each select = "it:modulafContent/it:module[@layout='header' and @option!='may']">
				<xsl:call-template name="header" />
			</xsl:for-each>

			<xsl:variable name="leftList" select="it:modulafContent/it:module[@layout='left' and @option!='may']" />
			<xsl:variable name="mainList" select="it:modulafContent/it:module[@layout='main' and @option!='may']" />
			<xsl:variable name="rightList" select="it:modulafContent/it:module[@layout='right' and @option!='may']" />

			<xsl:for-each select = "it:modulafContent/it:module[@layout='upper']">
				<xsl:call-template name="upper" />
			</xsl:for-each>

			<xsl:for-each select = "$mainList">
				<xsl:call-template name="main" />
			</xsl:for-each>

			<xsl:call-template name="divNext" />

			<xsl:for-each select = "it:modulafContent/it:module[@layout='lower']">
				<xsl:call-template name="lower" />
			</xsl:for-each>
			
			<xsl:if test="count($leftList) > 0">
				<xsl:for-each select = "$leftList">
					<xsl:call-template name="left" />
				</xsl:for-each>
			</xsl:if>

			<xsl:if test="count($rightList) > 0">
				<xsl:for-each select = "$rightList">
					<xsl:call-template name="right" />
				</xsl:for-each>
			</xsl:if>

			<xsl:call-template name="divNavigation" />

			<xsl:for-each select = "it:modulafContent/it:module[@layout='footer' and @option!='may']">
				<xsl:call-template name="footer" />
			</xsl:for-each>

			<xsl:if test="it:modulafContent/it:returnURI">
				<p>[<a href="{it:modulafContent/it:returnURI}">戻る</a>]</p>
			</xsl:if>

		</body>
		</html>
	</xsl:template>

</xsl:stylesheet>
